#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use Pod::Usage;

my %opt;
GetOptions(\%opt, "logdir|p=s", "gzipprg|g=s", "help|h")
	or pod2usage(-exitstatus => 2, -verbose => 0);

if($opt{help}) {
	pod2usage(-exitstatus => 0, -verbose => 1);
}


my $REPORT_DIR = $opt{logdir} || "/var/log/hspc";
my $GZIP = $opt{gzipprg} || "gzip";

opendir LOGDIR, $REPORT_DIR or pod2usage("Can't open log directory: $!");
my @files = map {$REPORT_DIR . "/" . $_}
		grep { /(rep|p)\d\d\d\d-\d\d-\d\d_\d\d-\d\d-\d\d(\.\d+)?$/ }
			readdir LOGDIR;
closedir LOGDIR;

for(@files) {
	`$GZIP $_`;
}

__END__

=pod

=head1 NAME

hspc_gzip_bugreport.pl -- look for bugreport files and gzip them.

=head1 SYNOPSIS

B<hspc_gzip_bugreport.pl> [options]

use B<-h> or B<--help> switch for more details

=head1 OPTIONS

=over 4

=item B<-p | --logdir>

Path to the directory where to look for bugreports to gzip.

=item B<-g | --gzipprg>

Program to use to archive files. Obviously, there actually must be such a program
on the system where this program is being run.

=back

=head1 DESCRIPTION

This script is intended to be used from cron.

=head1 COPYRIGHT

Copyright 2005 SWsoft

=cut
