#!/bin/sh

HOSTNAME="/bin/hostname -f"

DBUSER=`cat /etc/hspc/hspc.conf |grep MAIN_DB_USER |sed -e 's/^MAIN_DB_USER\s*=\s*//'`
DBPASS=`cat /etc/hspc/hspc.conf |grep MAIN_DB_PASS |sed -e 's/^MAIN_DB_PASS\s*=\s*//'`

SKDBUSER=`cat /etc/hspc/hspc.conf |grep SK_DB_USER |sed -e 's/^SK_DB_USER\s*=\s*//'`
SKDBPASS=`cat /etc/hspc/hspc.conf |grep SK_DB_PASS |sed -e 's/^SK_DB_PASS\s*=\s*//'`

SSDBUSER=`cat /etc/hspc/hspc.conf |grep SS_DB_USER |sed -e 's/^SS_DB_USER\s*=\s*//'`
SSDBPASS=`cat /etc/hspc/hspc.conf |grep SS_DB_PASS |sed -e 's/^SS_DB_PASS\s*=\s*//'`

SESDBUSER=`cat /etc/hspc/hspc.conf |grep SESSION_DB_USER |sed -e 's/^SESSION_DB_USER\s*=\s*//'`
SESDBPASS=`cat /etc/hspc/hspc.conf |grep SESSION_DB_PASS |sed -e 's/^SESSION_DB_PASS\s*=\s*//'`

if [ -f "${SHARE_VAR_FILE}" ] ; then
	. ${SHARE_VAR_FILE}
fi

runmysql() {
	local SQLUSER="root"

	if [ -f "/etc/psa/.psa.shadow" ] ; then
		SQLUSER="admin"
		SQLPASS="`cat /etc/psa/.psa.shadow`"
	fi

	if [ "X${SQLPASS}" = "X" ]; then
		mysql -u root || return $?
	else
		mysql -u${SQLUSER} -p${SQLPASS} || return $?
	fi
}

grantmysql() {
	echo "grant all privileges on $4 to $1@'$3' \
		  identified by '$2';" | runmysql || exit $?
}

set_hspc_db_users() {
	# Creating HSPC mysql users
	grantmysql ${DBUSER} ${DBPASS} "%" "aspc.*" || exit $?
	grantmysql ${DBUSER} ${DBPASS} "localhost" "aspc.*" || exit $?
	grantmysql ${DBUSER} ${DBPASS} "`${HOSTNAME}`" "aspc.*" || exit $?

	grantmysql ${DBUSER} ${DBPASS} "%" "aspc_mutex.*" || exit $?
	grantmysql ${DBUSER} ${DBPASS} "localhost" "aspc_mutex.*" || exit $?
	grantmysql ${DBUSER} ${DBPASS} "`${HOSTNAME}`" "aspc_mutex.*" || exit $?

	grantmysql ${SKDBUSER} ${SKDBPASS} "%" "sk.*" || exit $?
	grantmysql ${SKDBUSER} ${SKDBPASS} "localhost" "sk.*" || exit $?
	grantmysql ${SKDBUSER} ${SKDBPASS} "`${HOSTNAME}`" "sk.*" || exit $?

	grantmysql ${SSDBUSER} ${SSDBPASS} "%" "ss.*" || exit $?
	grantmysql ${SSDBUSER} ${SSDBPASS} "localhost" "ss.*" || exit $?
	grantmysql ${SSDBUSER} ${SSDBPASS} "`${HOSTNAME}`" "ss.*" || exit $?

	grantmysql ${SESDBUSER} ${SESDBPASS} "%" "dbsession.*" || exit $?
	grantmysql ${SESDBUSER} ${SESDBPASS} "localhost" "dbsession.*" || exit $?
	grantmysql ${SESDBUSER} ${SESDBPASS} "`${HOSTNAME}`" "dbsession.*" || exit $?
	echo "use mysql; flush privileges;" | runmysql || exit $?

	#### TODO: configure PowerDNS
}

set_hspc_db_users
